@@ -36,6 +36,7 @@ E = xghtml.E
 from lino.core import constants
 
 from lino.core.dbutils import resolve_model
+from lino.core.dbutils import navinfo
 from lino.core import layouts
 #~ from lino.core import changes
 from lino.core import fields
@@ -461,7 +462,8 @@ class Action(Parametrizable,Permittable):
       
     def __get__(self, instance, owner):
         """
-        Getting an Action instance of an *Actor* (which is a class) will return the 
+        Getting an Action instance of an *Actor* (which is a class) 
+        will return the 
         """
         #~ print "__get__ %r / %r / %r" % (self, instance, owner)
         if instance is None:
@@ -469,7 +471,6 @@ class Action(Parametrizable,Permittable):
         return InstanceAction(self,instance.get_default_table(),instance,owner)
         
         
-        
     def as_html(self,ar):
         return "Oops, no as_html method for %s" % self
 
@@ -529,12 +530,15 @@ class Action(Parametrizable,Permittable):
         return ar.get_title()
         
     def __repr__(self):
-        return "%s %s.%s" % (self.__class__.__name__,self.defining_actor,self.action_name)
+        #~ return "<%s %s.%s>" % (self.__class__.__name__,self.defining_actor,self.action_name)
+        if self.label is None:
+            return "<%s %s>" % (self.__class__.__name__,self.action_name)
+        return "<%s %s (%r)>" % (self.__class__.__name__,self.action_name,unicode(self.label))
         
-    def __str__(self):
-        if self.defining_actor is None:
-            return repr(self)
-        return unicode(self.defining_actor.label).encode('ascii','replace') + ' : ' + unicode(self.label).encode('ascii','replace')
+    #~ def __str__(self):
+        #~ if self.defining_actor is None:
+            #~ return repr(self)
+        #~ return unicode(self.defining_actor.label).encode('ascii','replace') + ' : ' + unicode(self.label).encode('ascii','replace')
         
     def unused__str__(self):
         raise Exception("20121003 Must use full_name(actor)") 
@@ -607,13 +611,14 @@ class Action(Parametrizable,Permittable):
     def run_from_code(self,obj,ar,**kw):
         return self.run_from_ui(obj,ar,**kw)
         
-    #~ def run_from_ui(self,elem,ar,**kw):
-        #~ raise NotImplementedError("%s has no run() method" % self.__class__)
+    def run_from_ui(self,row,ar,**kw):
+        """
+        Execute the action on the given `row`. 
+        `ar` is an :class:`ActionRequest <lino.core.requests.ActionRequest>` 
+        object representing the context where the action is running.
+        """
+        raise NotImplementedError("%s has no run_from_ui() method" % self.__class__)
 
-    #~ def request(self,*args,**kw):
-        #~ kw.update(action=self)
-        #~ return self.defining_actor.request(*args,**kw)
-        
     def action_param_defaults(self,ar,obj,**kw):
         """
         Same as Actor.param_defaults, except that here it is a instance method
@@ -666,13 +671,6 @@ class RowAction(Action):
         h += ")"
         return h 
         
-    def run_from_ui(self,row,ar,**kw):
-        """
-        Execute the action on the given `row`. `ar` is an :class:`ActionRequest <lino.core.requests.ActionRequest>` 
-        object representing the context where the action is running.
-        """
-        raise NotImplementedError("%s has no run() method" % self.__class__)
-
     #~ def get_action_permission(self,user,obj):
         #~ return self.actor.get_row_permission(self,ar,obj)
             
@@ -692,6 +690,8 @@ class RedirectAction(Action):
 
 
 class GridEdit(TableAction):
+    
+    #~ debug_permissions = 20130429 # Melanie doesn't see :menulabel:`Explorer --> Courses`
   
     use_param_panel = True
     show_in_workflow = False
@@ -814,7 +814,7 @@ class ShowDetailAction(RowAction):
         ah = ar.ah
         ba = ar.bound_action
         rpt = ar.actor
-        from lino.ui import views
+
         
         navigator = None
         if pk and pk != '-99999' and pk != '-99998':
@@ -824,15 +824,15 @@ class ShowDetailAction(RowAction):
                 #~ raise Exception("20120327 %s.get_row_by_pk(%r)" % (rpt,pk))
             if ar.actor.show_detail_navigator:
               
-                navinfo = views.navinfo(ar,elem)
-                if navinfo:
+                ni = navinfo(ar.data_iterator,elem)
+                if ni:
                     buttons = []
                     buttons.append( ('*',_("Home"), '/' ))
                     
-                    buttons.append( ('<<',_("First page"), ar.pk2url(navinfo['first']) ))
-                    buttons.append( ('<',_("Previous page"), ar.pk2url(navinfo['prev']) ))
-                    buttons.append( ('>',_("Next page"), ar.pk2url(navinfo['next']) ))
-                    buttons.append( ('>>',_("Last page"), ar.pk2url(navinfo['last']) ))
+                    buttons.append( ('<<',_("First page"), ar.pk2url(ni['first']) ))
+                    buttons.append( ('<',_("Previous page"), ar.pk2url(ni['prev']) ))
+                    buttons.append( ('>',_("Next page"), ar.pk2url(ni['next']) ))
+                    buttons.append( ('>>',_("Last page"), ar.pk2url(ni['last']) ))
                         
                     chunks = []
                     for text,title,url in buttons:
@@ -1063,7 +1063,10 @@ def action(*args,**kw):
     In practice you'll possibly use:
     :attr:`label <Action.label>`,
     :attr:`help_text <Action.help_text>` and
-    :attr:`required <Action.required>`
+    :attr:`required <Action.required>`.
+    
+    The decorated function must return a `dict` which allowed 
+    keys are defined in :attr:`lino.ui.base.ACTION_RESPONSES`.
     """
     def decorator(fn):
         kw.setdefault('custom_handler',True)
