@@ -296,6 +296,12 @@ class AppyBuildMethod(SimpleBuildMethod):
         #~ from lino.models import get_site_config
         #~ from appy.pod.renderer import Renderer
         #~ renderer = None
+        """
+        When the source string contains non-ascii characters, then 
+        we must convert it to a unicode string.
+        """
+        def translate(s):
+            return _(s.decode('utf8'))
         from lino import dd
         context = dict(self=elem,
             dtos=dd.dtos,
@@ -311,7 +317,7 @@ class AppyBuildMethod(SimpleBuildMethod):
             #~ restify=restify,
             #~ site_config = get_site_config(),
             site_config=settings.SITE.site_config,
-            _ = _,
+            _ = translate,
             #~ knowledge_text=fields.knowledge_text,
             )
         lang = str(elem.get_print_language(self))
@@ -843,7 +849,7 @@ class TypedPrintable(CachedPrintable):
         tplname = ptype.template or bm.default_template
         if not tplname.endswith(bm.template_ext):
             raise Warning(
-              "Invalid template %r configured for %s %r (expected filename ending with %r)." %
+              "Invalid template '%s' configured for %s '%s' (expected filename ending with '%s')." %
               (tplname,ptype.__class__.__name__,unicode(ptype),bm.template_ext))
         return [ tplname ]
         #~ return [ ptype.get_templates_group() + '/' + ptype.template ]
