@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2012 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 """
 """
 
-#~ import logging
-#~ logger = logging.getLogger(__name__)
+import logging
+logger = logging.getLogger(__name__)
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -30,17 +30,18 @@ from django.contrib.contenttypes import generic
 #~ logger.debug(__file__+' : started')
 
 from lino import dd
-from lino.utils import perms
 from lino import mixins
-from lino.modlib.contacts import models as contacts
-#~ from lino.modlib.cal.models import DurationUnit, update_auto_task
-from lino.modlib.cal.models import DurationUnit, update_reminder
+#~ from lino.modlib.contacts import models as contacts
+#~ from lino.modlib.cal.models import DurationUnits, update_reminder
 
-class UploadType(models.Model):
+#~ contacts = dd.resolve_app('contacts')
+cal = dd.resolve_app('cal')
+
+class UploadType(dd.Model):
     
     class Meta:
-        verbose_name = _("upload type")
-        verbose_name_plural = _("upload types")
+        verbose_name = _("Upload Type")
+        verbose_name_plural = _("Upload Types")
         
     name = models.CharField(max_length=200,verbose_name=_('Name'))
     
@@ -48,6 +49,7 @@ class UploadType(models.Model):
         return self.name
         
 class UploadTypes(dd.Table):
+    required = dd.required(user_level='admin')
     model = 'uploads.UploadType'
     column_names = "name *"
     order_by = ["name"]
@@ -59,10 +61,14 @@ class Upload(
     #~ mixins.Reminder, 
     mixins.AutoUser,
     mixins.CreatedModified,
-    mixins.Owned):
+    mixins.Controllable):
     
-    allow_cascaded_delete = True
+    #~ allow_cascaded_delete = ['']
     
+    class Meta:
+        verbose_name = _("Upload")
+        verbose_name_plural = _("Uploads")
+        
     type = models.ForeignKey("uploads.UploadType",
       blank=True,null=True)
       #~ verbose_name=_('upload type'))
@@ -98,25 +104,42 @@ class Upload(
         
     def update_reminders(self):
         """
-        Also called from :func:`lino.apps.dsbe.models.update_all_reminders`.
+        Also called from :func:`lino_welfare.modelib.pcsw.models.update_all_reminders`.
         """
         #~ logger.info("Upload.update_reminders() %s : owner is %s", self.pk, self.owner)
         
-        update_reminder(1,self,self.user,
+        cal.update_reminder(1,self,self.user,
           self.valid_until,
-          _("%s expires" % (self.type)),
-          2,DurationUnit.months)
+          _("%s expires") % self.type,
+          2,cal.DurationUnits.months)
       
-    def update_owned_instance(self,task):
-        #~ logger.info("Upload.update_owned_instance() %s : owner is %s", self.pk, self.owner)
-        mixins.AutoUser.update_owned_instance(self,task)
-        mixins.Owned.update_owned_instance(self,task)
+    #~ def update_owned_instance(self,task):
+        #~ # logger.info("Upload.update_owned_instance() %s : owner is %s", self.pk, self.owner)
+        #~ mixins.AutoUser.update_owned_instance(self,task)
+        #~ mixins.Controllable.update_owned_instance(self,task)
           
         
 class Uploads(dd.Table):
+    required = dd.required(user_level='admin')
     model = Upload
     order_by = ["modified"]
     column_names = "file user created modified *"
+    detail_layout = """
+    file user
+    type description 
+    # person company
+    # reminder_date reminder_text delay_value delay_type reminder_done
+    modified created owner
+    # show_date show_time 
+    # show_date time timestamp
+    """
+    
+    insert_layout = dd.FormLayout("""
+    file user
+    type description 
+    """,window_size=(60,'auto'))
+    
+    
     
 
 #~ class UploadsByPerson(Uploads):
@@ -129,14 +152,50 @@ class Uploads(dd.Table):
     #~ column_names = "file user person created modified"
     #~ show_slave_grid = False
     
-class UploadsByOwner(Uploads):
+class UploadsByController(Uploads):
+    required = dd.required()
     master_key = 'owner'
     column_names = "file type description user * "
     slave_grid_format = 'summary'
     
     
-class MyUploads(mixins.ByUser,Uploads):
+class MyUploads(Uploads,mixins.ByUser):
+    required = dd.required()
     #~ column_names = "file user person company owner created modified"
     column_names = "file description user owner *"
-    label = _("My uploads")
+    #~ label = _("My uploads")
     order_by = ["modified"]
+
+
+MODULE_LABEL = _("Uploads")
+
+linoweb = dd.resolve_app('ui')
+
+def setup_main_menu(site,ui,profile,m):
+    m  = m.add_menu("office",linoweb.OFFICE_MODULE_LABEL)
+    m.add_action(MyUploads)
+
+
+def site_setup(site):
+    pass
+  
+def setup_main_menu(site,ui,profile,m):
+    pass
+            
+  
+def setup_master_menu(site,ui,profile,m): 
+    pass
+  
+def unused_setup_my_menu(site,ui,profile,m): 
+    m  = m.add_menu("uploads",MODULE_LABEL)
+    m.add_action(MyUploads)
+    
+def setup_config_menu(site,ui,profile,m): 
+    m  = m.add_menu("office",linoweb.OFFICE_MODULE_LABEL)
+    #~ m  = m.add_menu("uploads",MODULE_LABEL)
+    m.add_action(UploadTypes)
+  
+def setup_explorer_menu(site,ui,profile,m):
+    m  = m.add_menu("office",linoweb.OFFICE_MODULE_LABEL)
+    #~ m  = m.add_menu("uploads",MODULE_LABEL)
+    m.add_action(Uploads)
